@@ -218,7 +218,7 @@ class CallSite:
         if argindex is not None:
             boundnode = getattr(context, "boundnode", None)
             # 2. first argument of instance/class method
-            if argindex == 0 and funcnode.type in ("method", "classmethod"):
+            if argindex == 0 and funcnode.type in {"method", "classmethod"}:
                 # context.boundnode is None when an instance method is called with
                 # the class, e.g. MyClass.method(obj, ...). In this case, self
                 # is the first argument.
@@ -246,7 +246,7 @@ class CallSite:
             # if we have a method, extract one position
             # from the index, so we'll take in account
             # the extra parameter represented by `self` or `cls`
-            if funcnode.type in ("method", "classmethod") and boundnode:
+            if funcnode.type in {"method", "classmethod"} and boundnode:
                 argindex -= 1
             # 2. search arg index
             try:
