@@ -22,6 +22,7 @@ at the same time.
 """
 import os
 import textwrap
+import types
 from tokenize import detect_encoding
 from typing import List, Union
 
@@ -29,7 +30,7 @@ from astroid import bases, modutils, nodes, raw_building, rebuilder, util
 from astroid._ast import get_parser_module
 from astroid.exceptions import AstroidBuildingError, AstroidSyntaxError, InferenceError
 from astroid.manager import AstroidManager
-from astroid.node_classes import NodeNG
+from astroid.nodes.node_classes import NodeNG
 
 objects = util.lazy_import("objects")
 
@@ -79,13 +80,15 @@ class AstroidBuilder(raw_building.InspectBuilder):
         super().__init__(manager)
         self._apply_transforms = apply_transforms
 
-    def module_build(self, module, modname=None):
+    def module_build(
+        self, module: types.ModuleType, modname: str = None
+    ) -> nodes.Module:
         """Build an astroid from a living module instance."""
         node = None
         path = getattr(module, "__file__", None)
         if path is not None:
             path_, ext = os.path.splitext(modutils._path_from_filename(path))
-            if ext in (".py", ".pyc", ".pyo") and os.path.exists(path_ + ".py"):
+            if ext in {".py", ".pyc", ".pyo"} and os.path.exists(path_ + ".py"):
                 node = self.file_build(path_ + ".py", modname)
         if node is None:
             # this is a built-in module
@@ -260,7 +263,7 @@ class AstroidBuilder(raw_building.InspectBuilder):
             pass
 
 
-def build_namespace_package_module(name, path):
+def build_namespace_package_module(name, path: str) -> nodes.Module:
     return nodes.Module(name, doc="", path=path, package=True)
 
 
