@@ -4,6 +4,7 @@
 # Copyright (c) 2016 Derek Gustafson <degustaf@gmail.com>
 # Copyright (c) 2018 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
+# Copyright (c) 2021 Craig Franklin <craigjfranklin@gmail.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 Alphadelta14 <alpha@alphaservcomputing.solutions>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
@@ -23,7 +24,6 @@ leads to an inferred FrozenSet:
 
 
 from astroid import bases, decorators, util
-from astroid.const import BUILTINS
 from astroid.exceptions import (
     AttributeInferenceError,
     InferenceError,
@@ -36,11 +36,11 @@ from astroid.nodes import node_classes, scoped_nodes
 objectmodel = util.lazy_import("interpreter.objectmodel")
 
 
-class FrozenSet(node_classes._BaseContainer):
+class FrozenSet(node_classes.BaseContainer):
     """class representing a FrozenSet composite node"""
 
     def pytype(self):
-        return "%s.frozenset" % BUILTINS
+        return "builtins.frozenset"
 
     def _infer(self, context=None):
         yield self
@@ -120,7 +120,7 @@ class Super(node_classes.NodeNG):
         return ast_builtins.getattr("super")[0]
 
     def pytype(self):
-        return "%s.super" % BUILTINS
+        return "builtins.super"
 
     def display_type(self):
         return "Super of"
@@ -266,10 +266,20 @@ class PartialFunction(scoped_nodes.FunctionDef):
         # A typical FunctionDef automatically adds its name to the parent scope,
         # but a partial should not, so defer setting parent until after init
         self.parent = parent
-        self.filled_positionals = len(call.positional_arguments[1:])
         self.filled_args = call.positional_arguments[1:]
         self.filled_keywords = call.keyword_arguments
 
+        wrapped_function = call.positional_arguments[0]
+        inferred_wrapped_function = next(wrapped_function.infer())
+        if isinstance(inferred_wrapped_function, PartialFunction):
+            self.filled_args = inferred_wrapped_function.filled_args + self.filled_args
+            self.filled_keywords = {
+                **inferred_wrapped_function.filled_keywords,
+                **self.filled_keywords,
+            }
+
+        self.filled_positionals = len(self.filled_args)
+
     def infer_call_result(self, caller=None, context=None):
         if context:
             current_passed_keywords = {
@@ -307,7 +317,7 @@ class Property(scoped_nodes.FunctionDef):
     type = "property"
 
     def pytype(self):
-        return "%s.property" % BUILTINS
+        return "builtins.property"
 
     def infer_call_result(self, caller=None, context=None):
         raise InferenceError("Properties are not callable")
